@@ -62,7 +62,7 @@ def addSwagger(apiInstance, appInstance):
         documentationUrl,
         DOCUMENTATION_FILE
     )
-    swaggerUi._static_folder = f'{OpenApiDocumentationFile(apiInstance)}{globals.OS_SEPARATOR}'
+    swaggerUi._static_folder = f'{OpenApiDocumentationFile.getDocumentationFolderPath(apiInstance)}{globals.OS_SEPARATOR}'
     # appInstance.documentationFolder = swaggerUi._static_folder
     appInstance.register_blueprint(swaggerUi, url_prefix=documentationUrl)
     OpenApiDocumentationFile.overrideDocumentation(apiInstance)
